@@ -8,7 +8,9 @@ __all__ = ['getConfig']
 defaultConfig = {
     'LOGGING.level': 'ERROR',
     'LOGIN.cookieFile': '.cookies',
-    'LOGIN.envFile': '.env'
+    'LOGIN.envFile': '.env',
+    # 密钥
+    'CRYPTO.key': 'HOWDUUDU'
 }
 
 def getConfig(name, file='config.ini', default={}):
@@ -21,3 +23,6 @@ def getConfig(name, file='config.ini', default={}):
             return cfg.get(name, key)
         return default.get(key) or defaultConfig.get('.'.join([name, key]))
     return getval
+
+if __name__ == "__main__":
+    print(getConfig('CRYPTO')('key'))
